# Python3 Toolbox 

A utility set for :
1 - Filesystem
2 - Time
3 - Print
4 - AWS
5 - Elasticsearch
6 - Image
7 - Network
... etc

For install :
> pip install py3toolbox

For upgrade:
> pip install py3toolbox --upgrade --no-cache-dir

For PyPi upload:
> twine upload dist/* --repository-url https://upload.pypi.org/legacy/ 

